==> gbsite-1.1.1.tar.gz: gbsite/templates/master/master_bugaddpage.php <==
<table cellspacing="0" cellpadding="4" border="0" width="100%">
<form method=post action="/project/<?= $project_name ?>/bugs/bugsubmit.php">
<tr>
<td colspan="3"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2">Thank you for taking time to report a bug regarding the <?= $project_name ?> project.</font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Type of Report:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<select name="class_id">
	<option value="0">- Select Bug Type -</option>
	<?
	    if(is_array($class_list)) {
	        reset($class_list);
	        while(list($id,$name) = @each($class_list)) {
	            echo "	<option value=\"$id\">$name</option>\n";
	        }
	    }
	 ?>
</select>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Priority:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<select name="priority">
	<option value="0">- Select Priority -</option>
	<option value="1">1 (Low)</option>
	<option value="2">2</option>
	<option value="3">3 (Medium)</option>
	<option value="4">4</option>
	<option value="5">5 (High)</option>
</select>
</td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Severity:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<select name="severity_id">
	<option value=0>- Select Severity -</option>
	<?
    while(list($id,$name) = @each($severity_list)) {
        echo "          <option value=\"$id\">$name</option>\n";
    }
 	?>
</select>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Software Version:</b><br><i>(<?= $project_name ?>)</i></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%" valign="top"><select name="version">
    <option value="Other">Other -- Please specify in description</option>
<? while(list($id,$name) = @each($version_list)) { ?>
    <option value="<?= $name ?>"><?= $name ?></option>
<? } ?>
                              </select></td>
</tr>
<tr>
<td nowrap valign="top"><font face="<?= $font_1 ?>" size="2"><b>Environment:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<textarea name="environment" cols="40" rows="5" WRAP></textarea>
<br><font face="<?= $font_1 ?>" size="2">OS version, DB version, relevant hardware info, etc.</font>
</td>
</tr>
<input type="hidden" name="os" value="NA">
<input type="hidden" name="os_version" value="NA">
<input type="hidden" name="platform" value="NA">
<!-- removed per neds request 10.25.00 - jb
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Operating System:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" name="os" maxlength="32"></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>OS Version:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" name="os_version" maxlength="32"></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Platform:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" name="platform" maxlength="32"></td>
</tr>
-->
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>One-Line Summary:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<input type="text" name="title" maxlength="100">
<br><font face="<?= $font_1 ?>" size="2"><i>ex; Crashes when saving</i></font>
</td>
</tr>
<tr>
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>Description:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><textarea name="description" cols="40" rows="10" WRAP></textarea></td>
</tr>
<?  if(empty($member_id)) { ?>
<tr bgcolor="<?= $color_7 ?>">
<td colspan="3"><font face="<?= $font_1 ?>" size="2"><i>Either you are not logged in, or you are not a registered user on <?= $official_name ?>. You are still allowed to submit bugs, but must provide us with an e-mail address.</i></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>E-mail Address:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" name="email" maxsize="128"></td>
</tr>
<? } ?>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td><input type="submit" value="Submit Bug"></td>
</tr>
</form>
</table>

==> gbsite-2.0.0.tar.gz: gbsite/templates/master/master_bugaddpage.php <==
<table cellspacing="0" cellpadding="4" border="0" width="100%">
<form method=post action="/project/<?= $project_name ?>/bugs/bugsubmit.php">
<? if($fr == "yes") { ?>
<input type="hidden" name="fr" value="yes">
<? } ?>
<tr>
<td colspan="3"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2">Thank you for taking time to <?= $fr != "yes" ? "report a bug" : "submit a feature request" ?> regarding the <?= $project_name ?> project.</font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Type of Report:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<select name="class_id">
	<option value="0">- Select Bug Type -</option>
	<?
	    if(is_array($class_list)) {
	        reset($class_list);
	        while(list($id,$name) = @each($class_list)) {
                    $selected = ($fr == "yes" && $name == "Feature request"
                                     ? " SELECTED" : "");
	            echo "	<option value=\"$id\"$selected>$name</option>\n";
	        }
	    }
	 ?>
</select>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Priority:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<select name="priority">
	<option value="0">- Select Priority -</option>
	<option value="1">1 (Low)</option>
	<option value="2">2</option>
	<option value="3">3 (Medium)</option>
	<option value="4">4</option>
	<option value="5">5 (High)</option>
</select>
</td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Severity:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<select name="severity_id">
	<option value=0>- Select Severity -</option>
	<?
    while(list($id,$name) = @each($severity_list)) {
        echo "          <option value=\"$id\">$name</option>\n";
    }
 	?>
</select>
</td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Software Version:</b><br><i>(<?= $project_name ?>)</i></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%" valign="top"><select name="version">
    <option value="Other">Other -- Please specify in description</option>
<? while(list($id,$name) = @each($version_list)) { ?>
    <option value="<?= $name ?>"><?= $name ?></option>
<? } ?>
                              </select></td>
</tr>
<tr>
<td nowrap valign="top"><font face="<?= $font_1 ?>" size="2"><b>Environment:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<textarea name="environment" cols="40" rows="5" WRAP></textarea>
<br><font face="<?= $font_1 ?>" size="2">OS version, DB version, relevant hardware info, etc.</font>
</td>
</tr>
<input type="hidden" name="os" value="NA">
<input type="hidden" name="os_version" value="NA">
<input type="hidden" name="platform" value="NA">
<!-- removed per neds request 10.25.00 - jb
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Operating System:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" name="os" maxlength="32"></td>
</tr>
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>OS Version:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" name="os_version" maxlength="32"></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Platform:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" name="platform" maxlength="32"></td>
</tr>
-->
<tr bgcolor="<?= $color_7 ?>">
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>One-Line Summary:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%">
<input type="text" name="title" maxlength="100">
<br><font face="<?= $font_1 ?>" size="2"><i>ex; Crashes when saving</i></font>
</td>
</tr>
<tr>
<td valign="top" nowrap><font face="<?= $font_1 ?>" size="2"><b>Description:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><textarea name="description" cols="40" rows="10" WRAP></textarea></td>
</tr>
<?  if(empty($member_id)) { ?>
<tr bgcolor="<?= $color_7 ?>">
<td colspan="3"><font face="<?= $font_1 ?>" size="2"><i>Either you are not logged in, or you are not a registered user on <?= $official_name ?>. You are still allowed to submit <?= $fr == "yes" ? "requests" : "bugs" ?>, but must provide us with an e-mail address.</i></font></td>
</tr>
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>E-mail Address:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" name="email" maxsize="128"></td>
</tr>
<? } ?>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td><input type="submit" value="Submit <?= $fr == "yes" ? "Request" : "Bug" ?>"></td>
</tr>
</form>
</table>
